summaryrefslogtreecommitdiffstats
path: root/jrt/src/com/yahoo/jrt/CryptoSocket.java
diff options
context:
space:
mode:
Diffstat (limited to 'jrt/src/com/yahoo/jrt/CryptoSocket.java')
-rw-r--r--jrt/src/com/yahoo/jrt/CryptoSocket.java6
1 files changed, 4 insertions, 2 deletions
diff --git a/jrt/src/com/yahoo/jrt/CryptoSocket.java b/jrt/src/com/yahoo/jrt/CryptoSocket.java
index 78308b76624..aac91362405 100644
--- a/jrt/src/com/yahoo/jrt/CryptoSocket.java
+++ b/jrt/src/com/yahoo/jrt/CryptoSocket.java
@@ -2,6 +2,8 @@
package com.yahoo.jrt;
+import com.yahoo.security.tls.authz.ConnectionAuthContext;
+
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.channels.SocketChannel;
@@ -103,10 +105,10 @@ public interface CryptoSocket {
public void dropEmptyBuffers();
/**
* Returns the security context for the current connection (given handshake completed),
* or empty if the current connection is not secure.
*/
- default public Optional<SecurityContext> getSecurityContext() {
+ default public Optional<ConnectionAuthContext> getConnectionAuthContext() {
return Optional.empty();
}
}
@@ -103,10 +105,10 @@ public interface CryptoSocket {
public void dropEmptyBuffers();
/**
- * Returns the security context for the current connection (given handshake completed),
+ * Returns the auth context for the current connection (given handshake completed),
* or empty if the current connection is not secure.
*/